<?php
/**
 * Core functions and definitions
 *
 * Sets up the theme
 *
 * The first function, foodland_initial_setup(), sets up the theme by registering support
 * for various features in WordPress, such as theme support, post thumbnails, navigation menu, and the like.
 *
 * foodland functions and definitions
 *
 * @package Theme Palace
 * @subpackage Foodland Pro
 * @since Foodland 1.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 1170;
}

if ( ! function_exists( 'foodland_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which runs
	 * before the init hook. The init hook is too late for some features, such as indicating
	 * support post thumbnails.
	 */
	function foodland_setup() {
		/**
		 * Get Theme Options Values
		 */
		$options 	= foodland_get_theme_options();
		/**
		 * Make theme available for translation
		 * Translations can be filed in the /languages/ directory
		 * If you're building a theme based on foodland, use a find and replace
		 * to change 'foodland' to the name of your theme in all the template files
		 */
		load_theme_textdomain( 'foodland', get_template_directory() . '/languages' );

		/**
		 * Add default posts and comments RSS feed links to head
		 */
		add_theme_support( 'automatic-feed-links' );

		/**
		* Add support for custom background image.
		*/
		$defaults = apply_filters( 'foodland_custom_background',  array(
			'default-image'          => '',
			'default-repeat'         => 'repeat',
			'default-position-x'     => 'center',
			'default-attachment'     => 'scroll',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
		));
		add_theme_support( 'custom-background', $defaults );

		/**
		 * Add theme support for site logo
		 *
		 * Since wordpress 4.5 
		 */
		if( 4.5 <= (float)( get_bloginfo( 'version' ) ) ){
			add_theme_support( 'custom-logo', array( 
				'flex-width'  => true,
				'flex-height' => false,
				'width'       => 250,
				'height'      => 50,
				'header-text' => array( 'site-title', 'site-description' ), 
			) );
		}

		/**
		 * Enable support for Post Thumbnails on posts and pages
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		 */
		add_theme_support( 'post-thumbnails' );

		// Add Foodland's custom image sizes
		add_image_size( 'foodland-slider', 640, 790, true ); // Used for Featured slider

		add_image_size( 'foodland-featured-content', 336, 224, true ); // used in Featured Content 

		add_image_size( 'foodland-header-large', 1200, 400, true); // used in Header image

		//Archive Images
		add_image_size( 'foodland-archive-left-right', 530, 530, true ); // used in Archive Left/Right image

		// Add image size for promotional headline
		add_image_size( 'foodland-promotional-page',570, 380, true ); // Used in Promotional headline page thumbnail image

		// Add image size for staff members
		add_image_size( 'staff-member-image',366, 355, true ); // Used in staff member image

		if( class_exists( 'jetpack' ) ){
			add_theme_support( 'nova_menu_item' ); // Enable jetpack food item support

			add_image_size( 'foodland-nova-archive',570, 500, true ); // Used in Nova Menu Archive page images
		}

		
	

		/**
		 * This theme uses wp_nav_menu() in one location.
		 */
		register_nav_menus( array(
			'primary' 	=> __( 'Primary Menu', 'foodland' ),
			'footer' 	=> __( 'Footer Menu', 'foodland' ),
		) );

		/**
		 * Enable support for Post Formats
		 */
		add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

		/**
		 * Setup Editor style
		 */
		add_editor_style( 'css/editor-style.css' );

		/**
		 * Setup title support for theme
		 * Supported from WordPress version 4.1 onwards
		 * More Info: https://make.wordpress.org/core/2014/10/29/title-tags-in-4-1/
		 */
		add_theme_support( 'title-tag' );

		/**
		 * Setup Infinite Scroll using JetPack if navigation type is set
		 */
		$pagination_type	= isset( $options['pagination_type'] ) ? $options['pagination_type'] : '';
		if( 'infinite-scroll-click' == $pagination_type ) {
			add_theme_support( 'infinite-scroll', array(
				'type'		=> 'click',
				'render'	=> 'foodland_infinite_scroll_render',
				'container' => 'jetpack-infinite',
				'footer'    => false,
			) );
		}
		else if ( 'infinite-scroll-scroll' == $pagination_type ) {
			//Override infinite scroll disable scroll option
        	update_option('infinite_scroll', true);

        	add_theme_support( 'infinite-scroll', array(
				'type'		=> 'scroll',
				'render'	=> 'foodland_infinite_scroll_render',
				'container' => 'jetpack-infinite',
				'footer'    => false,
			) );
		}

		/**
		 * Load up our new theme updater.
		 */
		if ( '1' != $options[ 'update_notifier' ] ) {
			if( is_admin() ){
				require( get_template_directory() . '/updater/theme-updater.php' );
			}
		}

		// Gutenberg support
		add_theme_support( 'editor-color-palette', array(
	       	array(
				'name' => esc_html__( 'Blue', 'foodland' ),
				'slug' => 'blue',
				'color' => '#2c7dfa',
	       	),
	       	array(
	           	'name' => esc_html__( 'Green', 'foodland' ),
	           	'slug' => 'green',
	           	'color' => '#7ed221',
	       	),
	       	array(
	           	'name' => esc_html__( 'Golden', 'foodland' ),
	           	'slug' => 'golden',
	           	'color' => '#ce9b23',
	       	),
	       	array(
	           	'name' => esc_html__( 'Black', 'foodland' ),
	           	'slug' => 'black',
	           	'color' => '#2f3633',
	       	),
	       	array(
	           	'name' => esc_html__( 'Grey', 'foodland' ),
	           	'slug' => 'grey',
	           	'color' => '#82868b',
	       	),
	   	));

		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-font-sizes', array(
		   	array(
		       	'name' => esc_html__( 'small', 'foodland' ),
		       	'shortName' => esc_html__( 'S', 'foodland' ),
		       	'size' => 12,
		       	'slug' => 'small'
		   	),
		   	array(
		       	'name' => esc_html__( 'regular', 'foodland' ),
		       	'shortName' => esc_html__( 'M', 'foodland' ),
		       	'size' => 16,
		       	'slug' => 'regular'
		   	),
		   	array(
		       	'name' => esc_html__( 'larger', 'foodland' ),
		       	'shortName' => esc_html__( 'L', 'foodland' ),
		       	'size' => 36,
		       	'slug' => 'larger'
		   	),
		   	array(
		       	'name' => esc_html__( 'huge', 'foodland' ),
		       	'shortName' => esc_html__( 'XL', 'foodland' ),
		       	'size' => 48,
		       	'slug' => 'huge'
		   	)
		));
		add_theme_support('editor-styles');
		add_theme_support( 'wp-block-styles' );
	}
endif; // foodland_setup
add_action( 'after_setup_theme', 'foodland_setup' );

if ( ! function_exists( 'foodland_infinite_scroll_render' ) ) :
	/**
	 * Set the code to be rendered on for calling posts,
	 * hooked to template parts when possible.
	 *
	 * Note: must define a loop.
	 */
	function foodland_infinite_scroll_render() {
		while ( have_posts() ): the_post();
			get_template_part( 'template-parts/content', get_post_format() );
		endwhile;
	}
endif;


if ( ! function_exists( 'foodland_featured_image_instruction' ) ) :
	/**
	 * Message to show in the Featured Image Meta box.
	 *
	 * @since Foodland 1.0
	 *
	 * @param string $content Admin post thumbnail HTML markup.
	 * @param int    $post_id Post ID.
	 * @return string HTML.
	 */
	function foodland_featured_image_instruction( $content, $post_id ) {

		$allowed = array( 'post', 'page' );
		if ( in_array( get_post_type( $post_id ), $allowed ) ) {
			$content .= '<strong>' . __( 'Recommended Header Featured Image Sizes', 'foodland' ) . ':</strong><br/>';
			$content .= __( 'Banner Image', 'foodland' ) . ' : 1200px X 400px';
		}

		return $content;

	}
endif;
add_filter( 'admin_post_thumbnail_html', 'foodland_featured_image_instruction', 10, 2 );

/**
 * Enqueue scripts and styles
 *
 * @uses  wp_register_script, wp_enqueue_script, wp_register_style, wp_enqueue_style, wp_localize_script
 * @action wp_enqueue_scripts
 *
 * @since Foodland 1.0
 */
function foodland_scripts() {
	$options = foodland_get_theme_options();

	$foodland_fonts  = array();
	$foodland_fonts[]= $options[ 'body_font' ];
	$foodland_fonts[]= $options[ 'title_font' ];
	$foodland_fonts[]= $options[ 'tagline_font' ];
	$foodland_fonts[]= $options[ 'content_title_font' ];
	$foodland_fonts[]= $options[ 'content_font' ];
	$foodland_fonts[]= $options[ 'headings_font' ];

	$web_fonts = array(
		'abril-fatface'	   => 'Abril+Fatface',
		'allerta'          => 'Allerta',
		'amaranth'         => 'Amaranth',
		'amatic-sc'		   => 'Amatic+SC',
		'andika'		   => 'Andika',
		'antic-didone'	   => 'Antic+Didone',
		'arapey'		   => 'Arapey',
		'arvo'             => 'Arvo',
		'asap'			   => 'Asap',
		'bitter'           => 'Bitter',
		'cantarell'        => 'Cantarell',
		'crete-round'	   => 'Crete+Round',
		'crimson-text'     => 'Crimson+Text',
		'cuprum'           => 'Cuprum',
		'dancing-script'   => 'Dancing+Script',
		'droid-sans'       => 'Droid+Sans',
		'droid-serif'      => 'Droid+Serif',
		'exo'              => 'Exo',
		'exo-2'            => 'Exo+2',
		'flamenco'     	   => 'Flamenco',
		'istok-web'        => 'Istok+Web',
		'josefin-sans'     => 'Josefin+Sans',
		'lato'             => 'Lato',
		'libre-baskerville'=> 'Libre+Baskerville',
		'lobster'          => 'Lobster',
		'lora'             => 'Lora',
		'medula-one'	   => 'Medula+One',
		'montserrat'       => 'Montserrat',
		'nobile'           => 'Nobile',
		'noto-serif'       => 'Noto+Serif',
		'neuton'           => 'Neuton',
		'open-sans'        => 'Open+Sans',
		'oswald'           => 'Oswald',
		'oxygen' 		   => 'Oxygen',
		'patua-one'        => 'Patua+One',
		'playfair-display' => 'Playfair+Display',
		'pt-sans'          => 'PT+Sans',
		'pt-serif'         => 'PT+Serif',
		'quattrocento-sans'=> 'Quattrocento+Sans',
		'roboto'           => 'Roboto',
		'roboto-slab'      => 'Roboto+Slab',
		'sacramento' 	   => 'Sacramento',
		'Sans-Serif'	   => 'Open+Sans',
		'slabo-27px'	   => 'Slabo+27px',
		'source-sans-pro'  => 'Source+Sans+Pro',
		'ubuntu'           => 'Ubuntu',
		'varela'           => 'Varela',
		'yanone-kaffeesatz'=> 'Yanone+Kaffeesatz',
	);

	$foodland_fonts = array_unique( $foodland_fonts ); // Make the array of fonts unique so that same font is not loaded twice
	$foodland_fonts = array_intersect( $foodland_fonts, array_keys( $web_fonts ) ); // Intersect selected fonts and webfonts to only recover fonts that need loading

	if ( empty( $options[ 'reset_typography' ] ) && !empty( $foodland_fonts ) ) {
		$web_fonts_stylesheet = '//fonts.googleapis.com/css?family=';

		$i	=	0;
		foreach( $foodland_fonts as $foodland_font ) {
			if( $i )// only set | to $web_fonts_stylesheet from second loop onwards
				$web_fonts_stylesheet .='|';

			$web_fonts_stylesheet .= $web_fonts[ $foodland_font ] . ':300,300italic,regular,italic,600,600italic';

			$i = 1;
		}

		$web_fonts_stylesheet .= '&subset=latin';

		wp_register_style( 'foodland-web-font', $web_fonts_stylesheet, false, null );

		$foodland_deps = array( 'foodland-web-font' );
	}
	else {
		$foodland_deps = false;
	}

	/**
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Enqueue styles required for the theme
	/**
	 * Add genericons style
	 */
	wp_enqueue_style( 'foodland-genericons', get_template_directory_uri() . '/css/genericons/genericons.css', false, '3.4.1' );
	/**
	 * Add  Meanmenu style
	 */
	wp_enqueue_style( 'foodland-meanmenu', get_template_directory_uri() . '/css/meanmenu.css', false, '3.4.1' );

	// blocks
	wp_enqueue_style( 'foodland-blocks', get_template_directory_uri() . '/css/blocks.css' );

	/**
	 * Add stylesheet
	 */
	wp_enqueue_style( 'foodland-style', get_stylesheet_uri(), $foodland_deps, FOODLAND_THEME_VERSION );

	// Enqueu scripts required for the theme
	wp_enqueue_script( 'skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.min.js', array(), '20130115', true );
	/**
	 * Loads up meanmenu script
	 */
	wp_enqueue_script( 'jquery-meanmenu', get_template_directory_uri() . '/js/jquery.meanmenu.min.js', array('jquery'), '20130115', true );

	/**
	 * Loads up Scroll Up script
	 */
	wp_enqueue_script( 'jquery-scrollup', get_template_directory_uri() . '/js/foodland-scrollup.min.js', array( 'jquery' ), '20160309', true  );
	
	/**
	 * Loads up fit vids
	 */
	wp_enqueue_script( 'jquery-fitvids', get_template_directory_uri() . '/js/fitvids.min.js', array( 'jquery' ), '1.1', true );

	/**
	 * Loads up html5.min for IE support
	 */
	wp_enqueue_script( 'html5', get_template_directory_uri() . '/js/html5.min.js' );

	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );

	/**
	 * Loads up Cycle JS
	 */
	if( $options['featured_slider_option'] != 'disabled' ) {

		// Register cycle2 plugin
		wp_register_script( 'jquery-cycle2', get_template_directory_uri() . '/js/jquery-cycle/jquery-cycle2.min.js', array( 'jquery' ), '2.1.6', true );

		/**
		 * Load transition plugins
		 */
		wp_enqueue_script( 'jquery-cycle2-carousel', get_template_directory_uri() . '/js/jquery-cycle/jquery-cycle2-carousel.min.js', array( 'jquery-cycle2' ), false, true );
		// Load cycle2.css

		wp_enqueue_style( 'cycle2-style', get_template_directory_uri() . '/css/cycle2.css' );
	}

	/**
	 * Enqueue custom script for foodland.
	 */
	wp_enqueue_script( 'foodland-custom-scripts', get_template_directory_uri() . '/js/foodland-custom-scripts.min.js', array( 'jquery' ), null );
}
add_action( 'wp_enqueue_scripts', 'foodland_scripts' );

/**
 * Enqueue editor styles for Gutenberg
 *
 * @since Foodland 1.0.0
 */
function foodland_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'foodland-block-editor-style', get_theme_file_uri( '/css/editor-blocks.css' ) );
}
add_action( 'enqueue_block_editor_assets', 'foodland_block_editor_styles' );

/**
 * Enqueue scripts and styles for Metaboxes
 * @uses  wp_enqueue_script, and  wp_enqueue_style
 *
 * @action admin_enqueue_scripts
 *
 * @since Foodland 1.0
 */
function foodland_enqueue_metabox_scripts( $hook ) {
	if( $hook == 'post.php' || $hook == 'post-new.php'  ){
		//CSS Styles
		wp_enqueue_style( 'foodland-metabox-tabs', get_template_directory_uri() . '/css/foodland-metabox-tabs.css' );

	    //Scripts
		wp_enqueue_script( 'foodland-metabox', get_template_directory_uri() . '/js/foodland-metabox.min.js', array( 'jquery', 'jquery-ui-tabs' ), '2013-10-05' );
	}
	return;
}
add_action( 'admin_enqueue_scripts', 'foodland_enqueue_metabox_scripts', 11 );

/**
* Recommended plugins
*/
require_once get_template_directory() . '/lib/class-tgm-plugin-activation.php';

require_once get_template_directory() . '/inc/tgm.php';

/**
 * Default Options.
 */
require get_template_directory() . '/inc/default-options.php';

/**
 * Custom Header.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Structure for foodland
 */
require get_template_directory() . '/inc/structure.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer-includes/customizer.php';

/**
 * Custom Menus
 */
require get_template_directory() . '/inc/menus.php';

/**
 * Load Slider file.
 */
require get_template_directory() . '/inc/featured-slider.php';

/**
 * Load promotional headline file.
 */
require get_template_directory() . '/inc/promotional-headline.php';

/**
 * Load Special product.
 */
require get_template_directory() . '/inc/todays-special.php';

/**
 * Load Featured Content.
 */
require get_template_directory() . '/inc/featured-content.php';

/**
 * Load Team members
 */
require get_template_directory() . '/inc/team-members.php';

/**
 * Load Breadcrumb file.
 */
require get_template_directory() . '/inc/breadcrumb.php';

/**
 * Load custom template for nova resturant jetpack.
 */
if ( class_exists( 'Nova_Restaurant' ) ) {

	require get_template_directory() . '/inc/custom-jetpack-template.php';

}

/**
 * Load Widgets and Sidebars
 */
require get_template_directory() . '/inc/widget-includes/widgets-core.php';


/**
 * Load Social Icons
 */
require get_template_directory() . '/inc/social-icons.php';

/**
 * Load Metaboxes
 */
require get_template_directory() . '/inc/metabox.php';

/**
 * Returns the options array for foodland.
 * @uses  get_theme_mod
 *
 * @since Foodland 1.0
 */
function foodland_get_theme_options() {
	$foodland_default_options = foodland_get_default_theme_options();

	return array_merge( $foodland_default_options , get_theme_mod( 'foodland_theme_options', $foodland_default_options ) ) ;
}


/**
 * Flush out all transients
 *
 * @uses delete_transient
 *
 * @action customize_save, foodland_customize_preview (see foodland_customizer function: foodland_customize_preview)
 *
 * @since Foodland 1.0
 */
function foodland_flush_transients(){
	delete_transient( 'foodland_featured_slider' );

	delete_transient( 'foodland_promotional_headline' );

	delete_transient( 'foodland_featured_content' );

	delete_transient( 'foodland_special_product' );

	delete_transient( 'foodland_team_members' );

	delete_transient( 'foodland_footer_content' );

	delete_transient( 'foodland_custom_css' );

	delete_transient( 'foodland_featured_image' );

	delete_transient( 'foodland_social_icons' );

	delete_transient( 'foodland_scrollup' );

	delete_transient( 'foodland_post_total_category' );

	//Add foodland default themes if there is no values
	if ( !get_theme_mod('foodland_theme_options') ) {
		set_theme_mod( 'foodland_theme_options', foodland_get_default_theme_options() );
	}
}
add_action( 'customize_save', 'foodland_flush_transients' );

/**
 * Flush out category transients
 *
 * @uses delete_transient
 *
 * @action edit_category
 *
 * @since Foodland 1.0
 */
function foodland_flush_category_transients(){
	delete_transient( 'foodland_post_total_category' );
}
add_action( 'edit_category', 'foodland_flush_category_transients' );


/**
 * Flush out post related transients
 *
 * @uses delete_transient
 *
 * @action save_post
 *
 * @since Foodland 1.0
 */
function foodland_flush_post_transients(){
	delete_transient( 'foodland_featured_slider' );

	delete_transient( 'foodland_promotional_headline' );

	delete_transient( 'foodland_special_product' );

	delete_transient( 'foodland_featured_content' );

	delete_transient( 'foodland_featured_image' );

	delete_transient( 'foodland_post_total_category' );
}
add_action( 'save_post', 'foodland_flush_post_transients' );

if ( ! function_exists( 'foodland_custom_css' ) ) :
	/**
	 * Enqueue Custon CSS
	 *
	 * @uses  set_transient, wp_head, wp_enqueue_style
	 *
	 * @action wp_enqueue_scripts
	 *
	 * @since Foodland 1.0
	 */
	function foodland_custom_css() {
		//foodland_flush_transients();
		$options 	= foodland_get_theme_options();

		$defaults 	= foodland_get_default_theme_options();

		$fonts 		= foodland_avaliable_fonts();

		if ( ( !$foodland_custom_css = get_transient( 'foodland_custom_css' ) ) ) {
			$foodland_custom_css ='';

			// Typography (Font Family) Options
			if( ! $options[ 'reset_typography' ] ) {
				if( $defaults[ 'body_font' ] != $options[ 'body_font' ] ) {
					$foodland_custom_css	.=  "body, button, input, select, textarea { font-family: ". $fonts [ $options[ 'body_font' ] ] [ 'label' ] ."; }". "\n";
				}
				if( $defaults[ 'title_font' ] != $options[ 'title_font' ] ) {
					$foodland_custom_css	.=  ".site-title { font-family: ". $fonts [ $options[ 'title_font' ] ] [ 'label' ] ."; }". "\n";
				}
				if( $defaults[ 'tagline_font' ] != $options[ 'tagline_font' ] ) {
					$foodland_custom_css	.=  ".site-description { font-family: ". $fonts [ $options[ 'tagline_font' ] ] [ 'label' ] ."; }". "\n";
				}
				if( $defaults[ 'content_title_font' ] != $options[ 'content_title_font' ] ) {
					$foodland_custom_css	.=  "#main .entry-title, #portfolio-overlay .view-caption h3.upercase { font-family: ". $fonts [ $options[ 'content_title_font' ] ] [ 'label' ] ."; }". "\n";
				}
				if( $defaults[ 'content_font' ] != $options[ 'content_font' ] ) {
					$foodland_custom_css	.=  "#main .entry-summary, #main .entry-content { font-family: ". $fonts [ $options[ 'content_font' ] ] [ 'label' ] ."; }". "\n";
				}
				if( $defaults[ 'headings_font' ] != $options[ 'headings_font' ] ) {
					$foodland_custom_css .=  "h1, h2, h3, h4, h5, h6 { font-family: ". $fonts [ $options[ 'headings_font' ] ] [ 'label' ] ."; }". "\n";
				}

			}
			// Header Color Options
			if( $defaults[ 'site_title_tagline_color' ] != get_header_textcolor() ) {
				$foodland_custom_css .=  "#masthead .site-title a, .site-description{ color: #".  get_header_textcolor() ."; }". "\n";
			}
			// Header Navigation menu
			if( $defaults[ 'header_nav_menu_color' ] != $options[ 'header_nav_menu_color' ] ){
				$foodland_custom_css .= "#site-navigation ul li a{ color: ". $options['header_nav_menu_color'] ."; }" . "\n";
			}
			// Theme color
			if( $defaults[ 'theme_color' ] != $options[ 'theme_color' ] ){
				$foodland_custom_css .= ".item.hover-on .product-info, a.rounded-btn, input.search-submit,.main-navigation ul ul, .reply-thread .form-submit input.btn-custom, .single-row .product-info.active, .reply-thread .form-submit input, .wpcf7-form input.wpcf7-submit, .mean-container a.meanmenu-reveal span, .mean-container .mean-nav, .mean-container .mean-nav, .mean-container .mean-nav ul, .mean-container .mean-nav ul li a.mean-expand, .mean-container .mean-nav ul li a.mean-expand:hover, .product-image .product-info { background: ". $options['theme_color'] ."; }" . "\n";
			}
			if( $defaults[ 'theme_color' ] != $options[ 'theme_color' ] ){
				$foodland_custom_css .= "#site-header .site-title a, .item-name-price .item-price, #portfolio-overlay .view-caption span.genericon-plus, #feature-slider .pdt-cost .rounded-btn, .entry-footer .comments-link a:hover, .entry-footer .edit-link:hover, .more-link:hover, .post-edit-link:hover, .type-post .entry-title a:hover, #latest-news .entry-header h3 a:hover, .site-title a:hover, .entry-footer .cat-links a:hover, #latest-news .more-link:hover, .item-name-price .item-name a:hover, .item-name-price .item-name span.food-categories a:hover, #footer-widgets .f-widget a:hover, .site-info .menu-links ul li a:hover, .nav-previous a:hover, .nav-previous a span:hover, .nav-next a span:hover, .nav-next a:hover, .about .upercase a, .reply-thread .comment-body a:hover, .logged-in-as a:hover,
				.pdt-cost .rounded-btn, span.cat-links a, .entry-meta a:hover, #latest-news .entry-header .entry-meta span:hover, #latest-news span.comments-link a:after, #latest-news span.posted-on a:after,  #latest-news .entry-header .entry-meta a:hover, .entry-meta a:hover, .entry-footer .comments-link a:hover, .entry-meta a:hover, .entry-footer .comments-link a:hover, .loader-container .genericon, #site-navigation ul li a:hover, .nav-collapse a:active, .nav-collapse .active a, #site-navigation ul li a:hover, #product-detail .product-descrp h2, #latest-news .entry-header .entry-meta span:hover, .entry-meta .posted-on time:hover,  .entry-meta .posted-on time:hover, .post-edit-link:hover, #latest-news span.comments-link a:hover, #latest-news span.edit-link a:hover, .mean-container a.meanmenu-reveal, span.cat-links, #site-navigation ul li.current_page_item > a,#latest-news .entry-meta span.comments-link a:after { color: ". $options['theme_color'] ."; }" . "\n";
			}
			if( $defaults[ 'theme_color' ] != $options[ 'theme_color' ] ){
				$foodland_custom_css .= " .mean-container a.meanmenu-reveal, .reply-thread input:focus, .reply-thread textarea:focus { border-color: ". $options['theme_color'] ."; }" . "\n";
			}

			$css = '';

			// Check if the custom CSS feature of 4.7 exists
			if ( function_exists( 'wp_update_custom_css_post' ) ) {
			    // Migrate any existing theme CSS to the core option added in WordPress 4.7.
			    if( !empty( $options['custom_css'] ) )
			    	$css = $options['custom_css'];
			    
			    if ( $css ) {
			        $core_css = wp_get_custom_css(); // Preserve any CSS already added to the core option.
			        $return = wp_update_custom_css_post( $core_css . $css );
					
			        if ( ! is_wp_error( $return ) ) {
			            // Remove the old theme_mod, so that the CSS is stored in only one place moving forward.
			   			$options['custom_css'] = '';
						set_theme_mod( 'foodland_theme_options', $options );
			        }
			    }
			} else {
			    // Back-compat for WordPress < 4.7.
				if ( isset( $options['custom_css'] ) ) {
					$foodland_custom_css .= $options['custom_css'];
				}
			}

			set_transient( 'foodland_custom_css', htmlspecialchars_decode( $foodland_custom_css ), 86940 );
		}
		wp_add_inline_style( 'foodland-style', $foodland_custom_css );
	}
endif; //foodland_custom_css
add_action( 'wp_enqueue_scripts', 'foodland_custom_css', 10  );

if ( ! function_exists( 'foodland_content_nav' ) ) :
	/**
	 * Display navigation to next/previous pages when applicable
	 *
	 * @since Foodland 1.0
	 */
	function foodland_content_nav( $nav_id ) {
		global $wp_query, $post;

		// Don't print empty markup on single pages if there's nowhere to navigate.
		if ( is_single() ) {
			$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
			$next = get_adjacent_post( false, '', false );

			if ( ! $next && ! $previous )
				return;
		}

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
			return;
		}

		$options			= foodland_get_theme_options();

		$pagination_type	= $options['pagination_type'];

		$nav_class = ( is_single() ) ? 'site-navigation post-navigation' : 'site-navigation paging-navigation';

		/**
		 * Check if navigation type is Jetpack Infinite Scroll and if it is not of custom post type and check if it is not disabled, else goto default pagination
		 * if it's active then disable pagination
		 */
		if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type )  && 'nova_menu_item' != get_post_type()  && class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) {
			return false;
		}

		?>
	        <nav role="navigation" id="<?php echo esc_attr( $nav_id ); ?>">
	        	<h3 class="screen-reader-text"><?php _e( 'Post navigation', 'foodland' ); ?></h3>
				<?php
				/**
				 * Check if navigation type is numeric and if Wp-PageNavi Plugin is enabled
				 */
				if ( 'numeric' == $pagination_type && function_exists( 'wp_pagenavi' ) ) {
					wp_pagenavi();
	            }
	            else { ?>
	                <div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'foodland' ) ); ?></div>
	                <div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'foodland' ) ); ?></div>
	            <?php
	            } ?>
	        </nav><!-- #nav -->
		<?php
	}
endif; // foodland_content_nav

if ( ! function_exists( 'foodland_comment' ) ) :
	/**
	 * Template for comments and pingbacks.
	 *
	 * Used as a callback by wp_list_comments() for displaying the comments.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;

		if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>

		<li id="comment-<?php comment_ID(); ?>" <?php comment_class( 'comment-holder' ); ?>>
			<div class="coment-wrap">
				<?php _e( 'Pingback:', 'foodland' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( 'Edit', 'foodland' ), '<span class="edit-link">', '</span>' ); ?>
			</div>

		<?php else : ?>

		<li id="comment-<?php comment_ID(); ?>" <?php comment_class( 'comment-holder' ); ?>>
			<div id="div-comment-<?php comment_ID(); ?>" class="comment-body">
				<div class="avatar-wrap">

					<?php if ( 0 != $args['avatar_size'] ) {
						printf( '<a href="%s">%s</a>', esc_url( get_comment_author_url() ),  get_avatar( $comment, $args['avatar_size'] ) . '</a>' );
						} ?>

				</div><!-- .comment-author -->
				<div class="comment-body">

					<div class="comment-header">
						<?php printf( '<h6 class="post-by">%s</h6>', esc_html( get_comment_author() ) ); ?>
						<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
							<time datetime="<?php comment_time( 'c' ); ?>">
								<?php printf( _x( '%1$s at %2$s', '1: date, 2: time', 'foodland' ), get_comment_date(), get_comment_time() ); ?>
							</time>
						</a>
						<?php edit_comment_link( __( 'Edit', 'foodland' ), '<span class="edit-link">', '</span>' ); ?>
					</div><!-- .comment-header -->

					<div class="comment-inner">
						<?php comment_text(); ?>

						<?php if ( '0' == $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'foodland' ); ?></p>
						<?php endif; ?>

					</div><!-- .comment-inner -->

					<div class="comment-footer">
					<?php
					comment_reply_link( array_merge( $args, array(
						'add_below' => 'div-comment',
						'depth'     => $depth,
						'max_depth' => $args['max_depth'],
						'before'    => '<div class="reply">',
						'after'     => '</div>',
					) ) );
				?>
					</div><!-- .comment-footer -->

				</div><!-- .comment-body -->

			</div><!-- .coment-wrap -->

		<?php
		endif;
	}
endif; // foodland_comment()


if ( ! function_exists( 'foodland_the_attached_image' ) ) :
	/**
	 * Prints the attached image with a link to the next attached image.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_the_attached_image() {
		$post                = get_post();
		$attachment_size     = apply_filters( 'foodland_attachment_size', array( 1200, 1200 ) );
		$next_attachment_url = wp_get_attachment_url();

		/**
		 * Grab the IDs of all the image attachments in a gallery so we can get the
		 * URL of the next adjacent image in a gallery, or the first image (if
		 * we're looking at the last image in a gallery), or, in a gallery of one,
		 * just the link to that image file.
		 */
		$attachment_ids = get_posts( array(
			'post_parent'    => $post->post_parent,
			'fields'         => 'ids',
			'numberposts'    => 1,
			'post_status'    => 'inherit',
			'post_type'      => 'attachment',
			'post_mime_type' => 'image',
			'order'          => 'ASC',
			'orderby'        => 'menu_order ID'
		) );

		// If there is more than 1 attachment in a gallery...
		if ( count( $attachment_ids ) > 1 ) {
			foreach ( $attachment_ids as $attachment_id ) {
				if ( $attachment_id == $post->ID ) {
					$next_id = current( $attachment_ids );
					break;
				}
			}

			// get the URL of the next image attachment...
			if ( $next_id )
				$next_attachment_url = get_attachment_link( $next_id );

			// or get the URL of the first image attachment.
			else
				$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
		}

		printf( '<a href="%1$s" title="%2$s" rel="attachment">%3$s</a>',
			esc_url( $next_attachment_url ),
			esc_attr( the_title_attribute( array( 'echo' => false ) ) ),
			wp_get_attachment_image( $post->ID, $attachment_size )
		);
	}
endif; //foodland_the_attached_image


if ( ! function_exists( 'foodland_entry_meta' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_entry_meta() {
		echo '<div class="entry-meta">';

		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		printf( '<span class="posted-on">' . __( 'posted on ', 'foodland') . '%1$s<a href="%2$s" rel="bookmark">%3$s</a></span>',
			sprintf( '<span class="screen-reader-text">'. _x( 'Posted on', 'Used before publish date.', 'foodland' ). '</span>'),
			 get_day_link( get_the_time('Y'),get_the_time('m'), get_the_time('d') ),
			$time_string
		);

		if ( is_singular() || is_multi_author() ) {
			printf( '<span class="byline"><span class="author vcard">%1$s<a class="url fn n" href="%2$s"> %3$s </a></span></span>',
				sprintf( '<span class="screen-reader-text">' . _x( 'Author', 'Used before post author name.', 'foodland' ) . '</span>' ),
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				esc_html( get_the_author() )
			);
		}

		echo '</div><!-- .entry-meta -->';
	}
endif; //foodland_entry_meta


if ( ! function_exists( 'foodland_tag_category' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_tag_category() {
		echo '<p class="entry-meta">';

		if ( 'post' == get_post_type() ) {
			$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'foodland' ) );
			if ( $categories_list && foodland_categorized_blog() ) {
				printf( '<span class="cat-links">%1$s' . __( '', 'foodland') . ' %2$s</span>',
					sprintf( '<span class="screen-reader-text">' . _x( 'Categories','Used before category names.', 'foodland' ) .'</span>' ),
					$categories_list
				);
			}

			$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'foodland' ) );
			if ( $tags_list ) {
				printf( '<span class="tags-links">%1$s%2$s</span>',
					sprintf( '<span class="screen-reader-text">' ._x( 'Tags', 'Used before tag names.', 'foodland'). '</span>' ),
					$tags_list
				);
			}

			// if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) {
			// echo '<span class="comments-link">';
			// comments_popup_link( esc_html__( ' Leave a comment', 'foodland' ), esc_html__( '1 Comment', 'foodland' ), esc_html__( '% Comments', 'foodland' ) );
			// echo '</span>';
			// }

			// edit_post_link( esc_html__( ' Edit', 'foodland' ), '<span class="edit-link">', '</span>' );
		}

		echo '</p><!-- .entry-meta -->';
	}
endif; //foodland_tag_category


if ( ! function_exists( 'foodland_tag_comment' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_tag_comment() {
		echo '<p class="entry-meta">';

		if ( 'post' == get_post_type() ) {

			if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link( esc_html__( 'Leave a comment', 'foodland' ), esc_html__( '1 Comment', 'foodland' ), esc_html__( '% Comments', 'foodland' ) );
			echo '</span>';
			}

			edit_post_link( esc_html__( ' Edit', 'foodland' ), '<span class="edit-link">', '</span>' );
		}

		echo '</p><!-- .entry-meta -->';
	}
endif; //foodland_tag_comment

/**
 * Returns true if a blog has more than 1 category
 *
 * @since Foodland 1.0
 */
function foodland_categorized_blog() {
	if ( false === ( $foodland_post_total_category = get_transient( 'foodland_post_total_category' ) ) ) {
		// Create an array of all the categories that are attached to posts
		$foodland_post_total_category = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts
		$foodland_post_total_category = count( $foodland_post_total_category );

		set_transient( 'foodland_post_total_category', $foodland_post_total_category );
	}

	if ( '1' != $foodland_post_total_category ) {
		// This blog has more than 1 category so foodland_categorized_blog should return true
		return true;
	} else {
		// This blog has only 1 category so foodland_categorized_blog should return false
		return false;
	}
}

if ( ! function_exists( 'foodland_nova_menu_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the menu section , tags.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_nova_menu_entry_footer() {
		global $post;

		echo '<p class="entry-meta">';
		// get menu sections
		$food_items_section     = wp_get_post_terms( $post->ID, 'nova_menu' );

		// check if at least one menu section is assigned
		if( count( $food_items_section ) > 0 ){
		
			$food_item_section_name = $food_items_section[0]->name ;
			$food_item_section_link = get_term_link( $food_items_section[0]->term_id, 'nova_menu' );

			printf( '<span class="menu-section">%1$s' . __( 'posted in', 'foodland') . ' %2$s</span>',
						sprintf( '<span class="screen-reader-text">' . _x( 'Menu Section','Used before menu section.', 'foodland' ) .'</span>' ),
						sprintf( '<a href="'. esc_url( $food_item_section_link ) .'" rel="menu section">'. esc_html( $food_item_section_name ) . '</a>' )
			);
		}

		// get menu labels
		$food_item_labels     = wp_get_post_terms( $post->ID, 'nova_menu_item_label' );
		// check if at least one menu label is assigned
		if( count( $food_item_labels ) > 0  ){
			$tag_lists = '';
			foreach ( $food_item_labels as $food_item_label ) {
				$tag_name  = $food_item_label->name;
				$tag_link  = get_term_link( $food_item_label->term_id, 'nova_menu_item_label' );
				$tag_lists =  $tag_lists .'<a href="' . esc_url( $tag_link ) . '" rel="menu label">' . esc_html( $tag_name ). ', ' . '</a>';
			}
			// $tag_lists = substr_replace( $tag_lists, '', -6 ); // remove last occurance comma (,) with ('') in the string

			printf( '<span class="menu-label">%1$s %2$s</span>',
						sprintf( '<span class="screen-reader-text">' . _x( 'Menu Labels','Used before menu tags.', 'foodland' ) .'</span>' ), wp_kses_data( $tag_lists )
			);
		}

		edit_post_link( esc_html__( ' Edit', 'foodland' ), '<span class="edit-link">', '</span>' );
		echo '</p><!-- .entry-meta -->';
	}
endif; //foodland_nova_menu_entry_footer

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @since Foodland 1.0
 */
function foodland_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'foodland_page_menu_args' );


/**
 * Filter in a link to a content ID attribute for the next/previous image links on image attachment pages
 *
 * @since Foodland 1.0
 */
function foodland_enhanced_image_navigation( $url, $id ) {
	if ( ! is_attachment() && ! wp_attachment_is_image( $id ) )
		return $url;

	$image = get_post( $id );
	if ( ! empty( $image->post_parent ) && $image->post_parent != $id )
		$url .= '#main';

	return $url;
}
add_filter( 'attachment_link', 'foodland_enhanced_image_navigation', 10, 2 );


/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 *
 * @since Foodland 1.0
 */
function foodland_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'footer-1' ) )
		$count++;

	if ( is_active_sidebar( 'footer-2' ) )
		$count++;

	if ( is_active_sidebar( 'footer-3' ) )
		$count++;

	if ( is_active_sidebar( 'footer-4' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
		case '4':
			$class = 'four';
			break;
	}

	if ( $class )
		echo 'class="' . $class . '"';
}


if ( ! function_exists( 'foodland_excerpt_length' ) ) :
	/**
	 * Sets the post excerpt length to n words.
	 *
	 * function tied to the excerpt_length filter hook.
	 * @uses filter excerpt_length
	 *
	 * @since Foodland 1.0
	 */
	function foodland_excerpt_length( $length ) {
		// Getting data from Customizer Options
		$options	= foodland_get_theme_options();
		$length		= $options['excerpt_length'];
		return $length;
	}
endif; //foodland_excerpt_length
add_filter( 'excerpt_length', 'foodland_excerpt_length' );


/**
 * Change the defult excerpt length of 30 to whatever passed as value
 *
 * @use excerpt(10) or excerpt (..)  if excerpt length needs only 10 or whatevere
 * @uses get_permalink, get_the_excerpt
 */
function foodland_excerpt_desired( $num ) {
    $excerpt = explode( ' ', get_the_excerpt(), $limit );
    array_pop( $excerpt );
    $excerpt = implode( " ",$excerpt )."<a href='" .esc_url( get_permalink() ) ." '></a>";
    return $excerpt;
}


if ( ! function_exists( 'foodland_continue_reading' ) ) :
	/**
	 * Returns a "Custom Continue Reading" link for excerpts
	 *
	 * @since Foodland 1.0
	 */
	function foodland_continue_reading() {
		// Getting data from Customizer Options
		$options		=	foodland_get_theme_options();
		$more_tag_text	= $options['excerpt_more_text'];

		return ' <a class="more-link" href="' . esc_url( get_permalink() ) . '">' .  sprintf( __( '%s', 'foodland' ) , esc_html( $more_tag_text ) ) . '</a>';
	}
endif; //foodland_continue_reading
add_filter( 'excerpt_more', 'foodland_continue_reading' );


if ( ! function_exists( 'foodland_excerpt_more' ) ) :
	/**
	 * Replaces "[...]" (appended to automatically generated excerpts) with foodland_continue_reading().
	 *
	 * @since Foodland 1.0
	 */
	function foodland_excerpt_more( $more ) {
		return foodland_continue_reading();
	}
endif; //foodland_excerpt_more
add_filter( 'excerpt_more', 'foodland_excerpt_more' );


if ( ! function_exists( 'foodland_custom_excerpt' ) ) :
	/**
	 * Adds Continue Reading link to more tag excerpts.
	 *
	 * function tied to the get_the_excerpt filter hook.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_custom_excerpt( $output ) {
		if ( has_excerpt() && ! is_attachment() ) {
			$output .= foodland_continue_reading();
		}
		return $output;
	}
endif; //foodland_custom_excerpt
add_filter( 'get_the_excerpt', 'foodland_custom_excerpt' );


if ( ! function_exists( 'foodland_more_link' ) ) :
	/**
	 * Replacing Continue Reading link to the_content more.
	 *
	 * function tied to the the_content_more_link filter hook.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_more_link( $more_link, $more_link_text ) {
	 	$options		=	foodland_get_theme_options();
		$more_tag_text	= $options['excerpt_more_text'];

		return str_replace( $more_link_text, $more_tag_text, $more_link );
	}
endif; //foodland_more_link
add_filter( 'the_content_more_link', 'foodland_more_link', 10, 2 );


if ( ! function_exists( 'foodland_body_classes' ) ) :
	/**
	 * Adds foodland layout classes to the array of body classes.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_body_classes( $classes ) {
		global $post, $wp_query;

		//Getting Ready to load data from Theme Options Panel
		$options 		= foodland_get_theme_options();
		// Check logo 
		if( 4.5 <= (float) get_bloginfo( 'version' ) ){
			has_custom_logo() ? $disable_logo = false : $disable_logo = true; 
		}
		else{
			$site_logo = $options['logo'];
			!empty( $site_logo ) ? $disable_logo = false : $disable_logo = true;
		}
		// Adds a class of group-blog to blogs with more than 1 published author
		if ( is_multi_author() ) {
			$classes[] = 'group-blog';
		}

		if( false == display_header_text() && $disable_logo ){
			$classes[] = ' no_logo_and_title';
		}
		if( !$disable_logo && ( true == $options['disable_tagline_in_mobile'] ) ){
			$classes[] = ' show_logo_disable_title_mobile';
		}

		if( ( '' != get_bloginfo( 'name' ) || '' !=  get_bloginfo( 'description' ) )){
			$classes[] = ' has_title';
		}

		if (! $disable_logo ){
			$classes [] = ' has_only_logo'  ;
		}

		if( 'disabled' == $options['single_post_image_layout'] ){
			$classes[] = ' single_page_image_disable';
		}

		$classes 	= apply_filters( 'foodland_body_classes', $classes );

		return $classes;
	}
endif; //foodland_body_classes
add_filter( 'body_class', 'foodland_body_classes' );


if ( ! function_exists( 'foodland_post_classes' ) ) :
	/**
	 * Adds foodland post classes to the array of post classes.
	 * used for supporting different content layouts
	 *
	 * @since Foodland 1.0
	 */
	function foodland_post_classes( $classes ) {
		//Getting Ready to load data from Theme Options Panel
		$options 		= foodland_get_theme_options();

		$contentlayout = $options['content_layout'];
		$contentlayout .= ' clear';

		if ( is_archive() || is_home() || is_search() || is_front_page() ) {
			$classes[] = $contentlayout;
		}

		return $classes;
	}
endif; //foodland_post_classes
add_filter( 'post_class', 'foodland_post_classes' );


if ( ! function_exists( 'foodland_archive_content_image' ) ) :
	/**
	 * Template for Featured Image in Archive Content
	 *
	 * To override this in a child theme
	 * simply create your own foodland_archive_content_image(), and that function will be used instead.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_archive_content_image() {
		$options 			= foodland_get_theme_options();

		$featured_image = $options['content_layout'];

		if ( has_post_thumbnail() && 'full-content' != $featured_image ) { ?>
			<figure class="entry-thumbnail one-half">
	            <a rel="bookmark" href="<?php the_permalink(); ?>">
	            <?php
						if ( $featured_image == 'excerpt-image-left' || $featured_image == 'excerpt-image-right' ) {
		                     the_post_thumbnail( 'foodland-archive-left-right' );
		                }
		               	elseif ( $featured_image == 'excerpt-full-image' ) {
		                     the_post_thumbnail( 'full' );
		                }
					?>
				</a>
	        </figure><!-- .entry-thumbnail-->
	   	<?php
		}
	}
endif; //foodland_archive_content_image
add_action( 'foodland_before_entry_container', 'foodland_archive_content_image', 10 );


if ( ! function_exists( 'foodland_single_content_image' ) ) :
	/**
	 * Template for Featured Image in Single Post
	 *
	 * To override this in a child theme
	 * simply create your own foodland_single_content_image(), and that function will be used instead.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_single_content_image() {
		global $post, $wp_query;
		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();
		if( $post) {
	 		if ( is_attachment() ) {
				$parent = $post->post_parent;
				$individual_featured_image = get_post_meta( $parent,'foodland-featured-image', true );
			} else {
				$individual_featured_image = get_post_meta( $page_id,'foodland-featured-image', true );
			}
		}

		if( empty( $individual_featured_image ) || ( !is_page() && !is_single() ) ) {
			$individual_featured_image = 'default';
		}

		// Getting data from Theme Options
	   	$options = foodland_get_theme_options();

		$featured_image = $options['single_post_image_layout'];

		if ( ( $individual_featured_image == 'disable' || '' == get_the_post_thumbnail() || ( $individual_featured_image=='default' && $featured_image == 'disabled') ) ) {
			echo '<!-- Page/Post Single Image Disabled or No Image set in Post Thumbnail -->';
			return false;
		}
		else {
			$class = '';

			if ( 'default' == $individual_featured_image ) {
				$class = $featured_image;
			}
			else {
				$class = 'from-metabox ' . $individual_featured_image;
			}

			?>
			<figure class="featured-image <?php echo $class; ?>">
                <?php
				if ( $individual_featured_image == 'large' || ( $individual_featured_image=='default' && $featured_image == 'large' ) ) {
                     the_post_thumbnail( 'large' );
                }
          
				elseif ( $individual_featured_image == 'header-image' || ( $individual_featured_image=='default' && $featured_image == 'header-image' ) ) {
					the_post_thumbnail( 'foodland-header-large' );
				}
				else {
					the_post_thumbnail( 'full' );
				} ?>
	        </figure>
	   	<?php
		}
	}
endif; //foodland_single_content_image
add_action( 'foodland_before_post_container', 'foodland_single_content_image', 10 );
add_action( 'foodland_before_page_container', 'foodland_single_content_image', 10 );


if ( ! function_exists( 'foodland_get_comment_section' ) ) :
	/**
	 * Comment Section
	 *
	 * @get comment setting from theme options and display comments sections accordingly
	 * @display comments_template
	 * @action foodland_comment_section
	 *
	 * @since Foodland 1.0
	 */
	function foodland_get_comment_section() {
		
			if( is_page() || is_single() )
				if ( comments_open() || '0' != get_comments_number() )
				comments_template();
	}
endif;

add_action( 'foodland_comment_section', 'foodland_get_comment_section', 10 );

/**
 * Footer Text
 *
 * @get footer text from theme options and display them accordingly
 * @display footer_text
 * @action foodland_footer
 *
 * @since Foodland 1.0
 */
function foodland_footer_content() {
	//foodland_flush_transients();
	if ( ( !$foodland_footer_content = get_transient( 'foodland_footer_content' ) ) ) {
		echo '<!-- refreshing cache -->';

		// get the data value from theme options
		$options                   = foodland_get_theme_options();
		
		$defaults                  = foodland_get_default_theme_options();
		
		$disable_social_media      = $options['disable_social_icon'];
		
		$social_media_links        = foodland_get_social_icons();
		
		$search                    = array( '[the-year]', '[site-link]' );
		
		$replace                   = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );
		
		$options['footer_content'] = str_replace( $search, $replace, $options['footer_content'] );
		
		$footer_content            = $options['footer_content'];


		if ( '' != $footer_content || !$disable_social_media || has_nav_menu( 'footer' ) ){
			$foodland_footer_content .=  '
				<div class="wrapper clear">
                	<div class="footer-bottom">';
            if( !$disable_social_media ){   		
            	$foodland_footer_content .= '
            			<div class="one-half">
							<div class="social-links">'. $social_media_links . '</div> <!-- .social-links -->
            			</div><!-- .one-half -->';
            }

            if(  has_nav_menu( 'footer' ) ){
                  
                $foodland_footer_content .= '
                		<div class="one-half">
                    		<div class="site-info">';
                    		if( has_nav_menu( 'footer' ) ){
                    			$menu_container_before = '<div class="menu-links">';
                    			$menu_container_after = '</div><!-- .menu-links -->';

                    			$foodland_footer_menu_args = array(
									'theme_location' => 'footer',
									'menu_class'     => 'clear foodland-nav-menu',
									'container'		 => false,
									'echo'			 => false,
				                );

                    			$foodland_footer_content .= $menu_container_before .
               					wp_nav_menu( $foodland_footer_menu_args ) . $menu_container_after ;
                    		}                      		
                      		$foodland_footer_content .= '
                    		</div><!-- .site-info -->
                    
                  		</div><!--one-half -->';
                }
         
            		if ('' != $footer_content ){
            			$foodland_footer_content .= '
            			<div class="clear"></clear>
            			<div class="copyright">          			
                      		<p>' . wp_kses_data( $footer_content ); 
                  		if ( function_exists( 'the_privacy_policy_link' ) ) {
						    $foodland_footer_content .= get_the_privacy_policy_link( ' | ' );
						}
                  		$foodland_footer_content .= '</p>
                      	</div><!-- .copyright -->';
            		}
            	$foodland_footer_content .= ' 
               		</div><!-- .footer-bottom -->
           		</div><!-- .wrapper -->';

	    	set_transient( 'foodland_footer_content', $foodland_footer_content, 86940 );
	    }
    }

    echo $foodland_footer_content;
}
add_action( 'foodland_footer', 'foodland_footer_content', 100 );


if ( ! function_exists( 'foodland_scrollup' ) ) {
	/**
	 * This function loads Scroll Up Navigation
	 *
	 * @action foodland_footer action
	 * @uses set_transient and delete_transient
	 */
	function foodland_scrollup() {
		//foodland_flush_transients();
		if ( !$foodland_scrollup = get_transient( 'foodland_scrollup' ) ) {

			// get the data value from theme options
			$options         = foodland_get_theme_options();
			$enable_scrollup = $options['enable_scrollup']; // check if scroll up option is enabled

			if( $enable_scrollup ){
			echo '<!-- refreshing cache -->';

				$foodland_scrollup =  '<a href="#masthead" id="scrollup" class="genericon"><span class="screen-reader-text">' . __( 'Scroll Up', 'foodland' ) . '</span></a>' ;
			}

			set_transient( 'foodland_scrollup', $foodland_scrollup, 86940 );
		}
		echo $foodland_scrollup;
	}
}
add_action( 'foodland_after', 'foodland_scrollup', 10 );


if ( ! function_exists( 'foodland_comment_defaults' ) ) :
	/**
	 * Modify Comment Form Defaults
	 *
	 * @uses comment_form_defaults filter
	 * @since Foodland 1.0
	 */
	function foodland_comment_defaults( $defaults ) {
		// get data value from theme options
	    $options = foodland_get_theme_options();
		$disablenote = $options[ 'disable_notes' ];

	 	if ( $disablenote == '1' ) :
			$defaults['comment_notes_after'] = '';
		endif;

		return $defaults;
	}
endif; //foodland_comment_defaults
add_filter( 'comment_form_defaults', 'foodland_comment_defaults' );


if ( ! function_exists( 'foodland_comment_form_fields' ) ) :
	/**
	 * Modify Comment Form Fields
	 *
	 * @uses comment_form_default_fields filter
	 * @since Foodland 1.0
	 */
	function foodland_comment_form_fields( $fields ) {
		// get data value from theme options
		$options = foodland_get_theme_options();
		$disableurl = $options[ 'disable_website_field' ];

		if ( isset( $fields['url'] ) && $disableurl == '1' ) {
			unset( $fields['url'] );
		}

		return $fields;

	}
endif; //foodland_comment_form_fields
add_filter( 'comment_form_default_fields', 'foodland_comment_form_fields' );


if ( ! function_exists( 'foodland_page_post_meta' ) ) :
	/**
	 * Post/Page Meta for Google Structure Data
	 */
	function foodland_page_post_meta() {
		$foodland_author_url = esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) );

		$foodland_page_post_meta = '<span class="post-time">' . __( 'Posted on', 'foodland' ) . ' <time class="entry-date updated" datetime="' . esc_attr( get_the_date( 'c' ) ) . '" pubdate>' . esc_html( get_the_date() ) . '</time></span>';
	    $foodland_page_post_meta .= '<span class="post-author">' . __( 'By', 'foodland' ) . ' <span class="author vcard"><a class="url fn n" href="' . $foodland_author_url . '" title="View all posts by ' . get_the_author() . '" rel="author">' .get_the_author() . '</a></span>';

		return $foodland_page_post_meta;
	}
endif; //foodland_page_post_meta


if ( ! function_exists( 'foodland_truncate_phrase' ) ) :
	/**
	 * Return a phrase shortened in length to a maximum number of characters.
	 *
	 * Result will be truncated at the last white space in the original string. In this function the word separator is a
	 * single space. Other white space characters (like newlines and tabs) are ignored.
	 *
	 * If the first `$max_characters` of the string does not contain a space character, an empty string will be returned.
	 *
	 * @since 1.5
	 *
	 * @param string $text            A string to be shortened.
	 * @param integer $max_characters The maximum number of characters to return.
	 *
	 * @return string Truncated string
	 */
	function foodland_truncate_phrase( $text, $max_characters ) {

		$text = trim( $text );

		if ( mb_strlen( $text ) > $max_characters ) {
			//* Truncate $text to $max_characters + 1
			$text = mb_substr( $text, 0, $max_characters + 1 );

			//* Truncate to the last space in the truncated string
			$text = trim( mb_substr( $text, 0, mb_strrpos( $text, ' ' ) ) );
		}

		return $text;
	}
endif; //foodland_truncate_phrase


if ( ! function_exists( 'foodland_get_the_content_limit' ) ) :
	/**
	 * Return content stripped down and limited content.
	 *
	 * Strips out tags and shortcodes, limits the output to `$max_char` characters, and appends an ellipsis and more link to the end.
	 *
	 * @since 1.0
	 *
	 * @param integer $max_characters The maximum number of characters to return.
	 * @param string  $more_link_text Optional. Text of the more link. Default is "(more...)".
	 * @param bool    $stripteaser    Optional. Strip teaser content before the more text. Default is false.
	 *
	 * @return string Limited content.
	 */
	function foodland_get_the_content_limit( $max_characters, $more_link_text = '(more...)', $stripteaser = false ) {

		$content = get_the_content( '', $stripteaser );

		//* Strip tags and shortcodes so the content truncation count is done correctly
		$content = strip_tags( strip_shortcodes( $content ), apply_filters( 'get_the_content_limit_allowedtags', '<script>,<style>' ) );

		//* Remove inline styles / scripts
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		//* Truncate $content to $max_char
		$content = foodland_truncate_phrase( $content, $max_characters );

		//* More link?
		if ( $more_link_text ) {
			$link   = apply_filters( 'get_the_content_more_link', sprintf( '<a href="%s" class="more-link">%s</a>', esc_url( get_permalink() ), esc_html( $more_link_text ) ),  $more_link_text );
			$output = sprintf( '<p>%s %s</p>', $content, $link );
		} else {
			$output = sprintf( '<p>%s</p>', $content );
			$link = '';
		}

		return apply_filters( 'foodland_get_the_content_limit', $output, $content, $link, $max_characters );

	}
endif; //foodland_get_the_content_limit


if ( ! function_exists( 'foodland_post_navigation' ) ) :
	/**
	 * Displays Single post Navigation
	 *
	 * @uses  the_post_navigation
	 *
	 * @action foodland_after_post
	 *
	 * @since Foodland 1.0
	 */
	function foodland_post_navigation() {
		$options	= foodland_get_theme_options();
		
		// Previous/next post navigation.
		the_post_navigation( array(
			'next_text' => '<span class="meta-nav" aria-hidden="true">' . __( 'Next &rarr;', 'foodland' ) . '</span> ' .
				'<span class="screen-reader-text">' . __( 'Next post:', 'foodland' ) . '</span> ',
			'prev_text' => '<span class="meta-nav" aria-hidden="true">' . __( '&larr; Previous', 'foodland' ) . '</span> ' .
				'<span class="screen-reader-text">' . __( 'Previous post:', 'foodland' ) . '</span> ',
		) );
	}
endif; //foodland_post_navigation
add_action( 'foodland_after_post', 'foodland_post_navigation', 10 );


if( ! function_exists( 'foodland_archive_class' )) :
	/**
	 * Displays Archive class
	 *
	 * @since Foodland 1.0
	 */
function foodland_archive_class(){
	$content_class  = '';
	$options        = foodland_get_theme_options();
	$content_layout = $options['content_layout'];

	if( has_post_thumbnail() && 'full-content' != $content_layout ){

		$content_class = 'news-content-wrapper one-half';

	}
	else
		$content_class = 'news-content-wrapper';

	return $content_class;
}
endif; //foodland_archive_class

if ( class_exists( 'Jetpack' ) ) :
	/**
	 * Displays Ratings for Nova menu items
	 *
	 * @action foodland_menu_ratings
	 *
	 * @since Foodland 1.0
	 */
	function foodland_get_menu_item_ratings( $rating_value ) {
		if( isset( $rating_value ) && !empty( $rating_value )){
			$stars = '<p class="rating">';
			for( $count = 1; $count <= 5; $count++ ){
				if( $count <= $rating_value ){
					$stars .= '<span class="genericon genericon-rating-full"></span>';
				}
				else{
					$stars .= '<span class="genericon genericon-rating-empty"></span>';
				}

			}
			$stars .= '</p>';
		}
		else{
			$stars = '';
		}
		return $stars ;
	}
endif; //foodland_post_navigation

if ( ! function_exists( 'foodland_nova_archive_content_image' ) ) :
	/**
	 * Template for Featured Image in nova menu Archive Content
	 *
	 * To override this in a child theme
	 * simply create your own foodland_nova_archive_content_image(), and that function will be used instead.
	 *
	 * @since Foodland 1.0
	 */
	function foodland_nova_archive_content_image() {
		$options 			= foodland_get_theme_options();

		$featured_image = $options['content_layout'];

		if ( has_post_thumbnail() && 'full-content' != $featured_image ) { ?>
			<figure class="entry-thumbnail one-half">
	            <a rel="bookmark" href="<?php the_permalink(); ?>">
	            <?php
					if ( $featured_image == 'excerpt-image-left' || $featured_image == 'excerpt-image-right' ) {
	                     the_post_thumbnail( 'foodland-nova-archive' );
	                }
	               	elseif ( $featured_image == 'excerpt-full-image' ) {
	                     the_post_thumbnail( 'full' );
	                }
				?>
				</a>
	        </figure><!-- .entry-thumbnail-->
	   	<?php
		}
		else{
		?>
			<figure class="entry-thumbnail one-half">
	            <a rel="bookmark" href="#">
	            	<img src="<?php echo get_template_directory_uri(); ?>/images/no-featured-image.png" width="570px" height="800px">
				</a>
	        </figure><!-- .entry-thumbnail-->
	    <?php 
		}
	}
endif; //foodland_nova_archive_content_image
add_action( 'foodland_before_nova_entry_container', 'foodland_nova_archive_content_image', 10 );

if ( ! function_exists( 'foodland_featured_slider_posts' ) ) :
	/**
	 * Function to return posts that are used in featured slider
	 *
	 * @since Foodland 1.0
	 */
	function foodland_featured_slider_posts() {
		$options     = foodland_get_theme_options();
		$slider_type = $options['featured_slider_type'];
		$no_of_posts = $options['featured_slide_number'];
		$post_list   = array();

		if( $options['exclude_slider_post'] && 'featured-post-slider' == $slider_type ){
			for( $i = 1; $i <= $no_of_posts; $i++ ){
				if( isset ( $options['featured_slider_post_' . $i] ) && $options['featured_slider_post_' . $i] > 0 ){
					$post_list	=	array_merge( $post_list, array( $options['featured_slider_post_' . $i] ) );
				}

			}
			return $post_list; // return posts id used in featured slider
		}
		else{
			return array(); // return empty array
		}
	}
endif;

if ( ! function_exists( 'foodland_slider_excerpt_limit' ) ) :
	/**
	 * Function to return excerpt content for Slider
	 *
	 * @return string Limited content.
	 */
	function foodland_slider_excerpt_limit( $length = 35, $post_obj = null ) {
		global $post;
		if ( is_null( $post_obj ) ) {
			$post_obj = $post;
		}
		$length = absint( $length );
		if ( $length < 1 ) {
			$length = 35;
		}
		$source_content = $post_obj->post_content;
		if ( ! empty( $post_obj->post_excerpt ) ) {
			$source_content = $post_obj->post_excerpt;
		}
		$source_content = preg_replace( '`\[[^\]]*\]`', '', $source_content );
		$trimmed_content = wp_trim_words( $source_content, $length, ' ...' );
		return $trimmed_content;
	}

endif; //foodland_slider_excerpt_limit